Maps categorical variables to the Annenberg Institute brand palette. Colors are ordered for maximum visual contrast.
Arguments
- ...
Additional arguments passed to
ggplot2::discrete_scale().
Maps categorical variables to the Annenberg Institute brand palette. Colors are ordered for maximum visual contrast.
Additional arguments passed to ggplot2::discrete_scale().