Maps categorical variables to the Annenberg Institute brand palette for fill aesthetics.
Arguments
- ...
Additional arguments passed to
ggplot2::discrete_scale().
Maps categorical variables to the Annenberg Institute brand palette for fill aesthetics.
Additional arguments passed to ggplot2::discrete_scale().