Returns the registered font family name for a given role. The font system prefers locally installed brand fonts and falls back to Google Fonts alternatives via showtext.
Usage
aib_font(role = c("heading", "body", "serif"))Returns the registered font family name for a given role. The font system prefers locally installed brand fonts and falls back to Google Fonts alternatives via showtext.
aib_font(role = c("heading", "body", "serif"))