R/aib_palettes.R
aib_pal.Rd
Returns a function that generates n colors from the AIB brand palette. Intended for use inside ggplot2 scale functions.
n
aib_pal()
A function that takes an integer n and returns n hex color codes.
pal <- aib_pal() pal(3) #> [1] "#1B3E6F" "#C00404" "#00AF9A"